@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2017 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -171,12 +171,12 @@ void AlbumDetailsDialog::show(AudioCdDevice *dev)
     artists.insert(dev->albumArtist());
 
     QList<Song> songs;
-    foreach (const MusicLibraryItem *i, dev->childItems()) {
+    for (const MusicLibraryItem *i: dev->childItems()) {
         songs.append(static_cast<const MusicLibraryItemSong *>(i)->song());
     }
     qSort(songs);
 
-    foreach (const Song &s, songs) {
+    for (const Song &s: songs) {
         QTreeWidgetItem *item=new QTreeWidgetItem(tracks);
         update(item, s);
         artists.insert(s.artist);
@@ -403,3 +403,5 @@ void AlbumDetailsDialog::coverSelected(const QImage &img, const QString &fileNam
         cover->setPixmap(QPixmap::fromImage(coverImage.img.scaled(cover->size(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation)));
     }
 }
+
+#include "moc_albumdetailsdialog.cpp"
