@@ -40,6 +40,7 @@
 #include "filejob.h"
 #include "support/configuration.h"
 #include "support/thread.h"
+#include "support/monoicon.h"
 #include <QTimer>
 #include <QDir>
 #include <QTemporaryFile>
@@ -753,9 +754,9 @@ static QTemporaryFile * saveImageToTemp(const QImage &img, const QString &name)
 
     int index=name.lastIndexOf('.');
     if (index>0) {
-        temp=new QTemporaryFile(QDir::tempPath()+"/cantata_XXXXXX"+name.mid(index));
+        temp=new QTemporaryFile("cantata_XXXXXX"+name.mid(index));
     } else {
-        temp=new QTemporaryFile(QDir::tempPath()+"/cantata_XXXXXX");
+        temp=new QTemporaryFile("cantata_XXXXXX");
     }
     img.save(temp);
     temp->close();
@@ -1211,7 +1212,7 @@ MtpDevice::MtpDevice(MusicLibraryModel *m, Solid::Device &dev, unsigned int busN
         DBUG << "setName" << opts.name;
         setData(opts.name);
     }
-    icn=Icon("multimedia-player");
+    icn=MonoIcon::icon(FontAwesome::mobilephone, Utils::monoIconColor());
 }
 
 MtpDevice::~MtpDevice()
@@ -1338,7 +1339,7 @@ void MtpDevice::addSong(const Song &s, bool overwrite, bool copyCover)
 
     if (transcoding) {
         deleteTemp();
-        tempFile=new QTemporaryFile(QDir::tempPath()+"/cantata_XXXXXX."+encoder.extension);
+        tempFile=new QTemporaryFile("cantata_XXXXXX."+encoder.extension);
         tempFile->setAutoRemove(false);
 
         if (!tempFile->open()) {
