@@ -546,7 +546,7 @@ void CoverDialog::downloadJobFinished()
             QTemporaryFile *temp=nullptr;
 
             if (isLarge || (reply->property(constThumbProperty).toString()==reply->property(constLargeProperty).toString())) {
-                temp=new QTemporaryFile(QDir::tempPath()+"/cantata_XXXXXX."+(format ? QString(QLatin1String(format)).toLower() : "png"));
+                temp=new QTemporaryFile("cantata_XXXXXX."+(format ? QString(QLatin1String(format)).toLower() : "png"));
 
                 if (temp->open()) {
                     if (!format) {
@@ -824,8 +824,8 @@ void CoverDialog::menuRequested(const QPoint &pos)
 {
     if (!menu) {
         menu=new QMenu(list);
-        showAction=menu->addAction(Icon("zoom-original"), tr("Display"));
-        removeAction=menu->addAction(Icon("list-remove"), tr("Remove"));
+        showAction=menu->addAction(tr("Display"));
+        removeAction=menu->addAction(tr("Remove"));
         connect(showAction, SIGNAL(triggered()), SLOT(showImage()));
         connect(removeAction, SIGNAL(triggered()), SLOT(removeImages()));
     }
