@@ -206,6 +206,17 @@ static inline bool isOnlineServiceImage(const Song &s)
 static Covers::Image serviceImage(const Song &s)
 {
     Covers::Image img;
+
+    if (s.hasExtraField(Song::OnlineImageCacheName)) {
+        img.fileName=s.extraField(Song::OnlineImageCacheName);
+        if (!img.fileName.isEmpty()) {
+            img.img=loadImage(img.fileName);
+            if (!img.img.isNull()) {
+                DBUG_CLASS("Covers") << s.onlineService() << img.fileName;
+                return img;
+            }
+        }
+    }
     img.fileName=OnlineService::iconPath(s.onlineService());
     if (!img.fileName.isEmpty()) {
         img.img=loadImage(img.fileName);
@@ -408,15 +419,20 @@ QString Covers::fixArtist(const QString &artist)
     static bool initialised=false;
     if (!initialised) {
         initialised=true;
-        QStringList dirs=QStringList() << Utils::dataDir() << CANTATA_SYS_CONFIG_DIR;
-        for (const QString &dir: dirs) {
-            if (dir.isEmpty()) {
-                continue;
-            }
 
-            QFile f(dir+QLatin1String("/tag_fixes.xml"));
-            if (f.open(QIODevice::ReadOnly)) {
-                QXmlStreamReader doc(&f);
+        QStringList files;
+        QString userDir=Utils::dataDir();
+
+        if (!userDir.isEmpty()) {
+            files.append(Utils::fixPath(userDir)+QLatin1String("tag_fixes.xml"));
+        }
+
+        files.append(":tag_fixes.xml");
+
+        for (const auto &f: files) {
+            QFile file(f);
+            if (file.open(QIODevice::ReadOnly)) {
+                QXmlStreamReader doc(&file);
                 while (!doc.atEnd()) {
                     doc.readNext();
                     if (doc.isStartElement() && QLatin1String("artist")==doc.name()) {
@@ -561,7 +577,7 @@ const QStringList & Covers::standardNames()
     if (!coverFileNames) {
         coverFileNames=new QStringList();
         QStringList fileNames;
-        fileNames << Covers::constFileName << QLatin1String("AlbumArt") << QLatin1String("folder");
+        fileNames << Covers::constFileName << QLatin1String("albumart") << QLatin1String("folder");
         for (const QString &fileName: fileNames) {
             for (int e=0; constExtensions[e]; ++e) {
                 *coverFileNames << fileName+constExtensions[e];
@@ -876,10 +892,16 @@ void CoverDownloader::onlineJobFinished()
             fileName=cacheName.isEmpty()
                         ? Utils::cacheDir(id.toLower(), true)+Covers::encodeName(song.album.isEmpty() ? song.albumArtist() : (song.albumArtist()+" - "+song.album))+(png ? ".png" : ".jpg")
                         : cacheName;
-            QFile f(fileName);
-            if (f.open(QIODevice::WriteOnly)) {
+            if (png && !cacheName.isEmpty()) {
+                QImage img=QImage::fromData(data, Covers::imageFormat(data));
+                img.save(fileName, "JPG");
                 DBUG << "Saved image to" << fileName;
-                f.write(data);
+            } else {
+                QFile f(fileName);
+                if (f.open(QIODevice::WriteOnly)) {
+                    DBUG << "Saved image to" << fileName;
+                    f.write(data);
+                }
             }
         }
         emit cover(job.song, img, fileName);
@@ -1229,7 +1251,7 @@ QPixmap * Covers::defaultPix(const Song &song, int size, int origSize)
     key+=QString::number(size);
     QPixmap *pix=cache.object(key);
     if (!pix) {
-        const Icon &icn=song.isArtistImageRequest() || song.isComposerImageRequest()
+        const QIcon &icn=song.isArtistImageRequest() || song.isComposerImageRequest()
                 ? Icons::self()->artistIcon
                 : podcast
                     ? Icons::self()->podcastIcon
@@ -1569,7 +1591,6 @@ Covers::Image Covers::locateImage(const Song &song)
     bool haveAbsPath=songFile.startsWith(Utils::constDirSep);
 
     if (song.isCantataStream()) {
-        songFile=QUrl(songFile).path();
         DBUG_CLASS("Covers") << "Stream file" << songFile;
     }
 
@@ -1600,7 +1621,7 @@ Covers::Image Covers::locateImage(const Song &song)
     }
 
     if (!songFile.isEmpty() && !songFile.startsWith("http:/") && !song.isCdda() &&
-        (haveAbsPath || (!MPDConnection::self()->getDetails().dir.isEmpty() && !MPDConnection::self()->getDetails().dir.startsWith(QLatin1String("http://")) ) ) ) {
+        (haveAbsPath || song.isCantataStream() || (!MPDConnection::self()->getDetails().dir.isEmpty() && !MPDConnection::self()->getDetails().dir.startsWith(QLatin1String("http://")) ) ) ) {
         dirName=song.isCantataStream() ? Utils::getDir(songFile)
                                        : songFile.endsWith(Utils::constDirSep)
                                             ? (haveAbsPath ? QString() : MPDConnection::self()->getDetails().dir)+songFile
