@@ -116,9 +116,7 @@ public:
 
 protected:
     void keyPressEvent(QKeyEvent *event) override;
-    #if defined Q_OS_WIN
-    void showEvent(QShowEvent *event);
-    #endif
+    void showEvent(QShowEvent *event) override;
     void closeEvent(QCloseEvent *event) override;
     void resizeEvent(QResizeEvent *event) override;
 
@@ -142,7 +140,7 @@ Q_SIGNALS:
     void startPlayingSongId(qint32);
     void setVolume(int);
     void outputs();
-    void enableOutput(int id, bool);
+    void enableOutput(quint32 id, bool);
     void setPriority(const QList<qint32> &ids, quint8 priority, bool decreasePriority);
     void addSongsToPlaylist(const QString &name, const QStringList &files);
     void showPreferencesPage(const QString &page);
@@ -267,7 +265,6 @@ private:
 
 private Q_SLOTS:
     void controlPlayQueueButtons();
-    void init();
     void toggleContext();
     void initMpris();
     void toggleMenubar();
@@ -278,6 +275,7 @@ private:
     qint32 lastSongId;
     PlayQueueProxyModel playQueueProxyModel;
     bool autoScrollPlayQueue;
+    bool singlePane;
     Action *prefAction;
     Action *refreshDbAction;
     Action *doDbRefreshAction;
