@@ -195,7 +195,7 @@ QString MPDConnection::Response::getError(const QByteArray &command)
 MPDConnectionDetails::MPDConnectionDetails()
     : port(6600)
     , dirReadable(false)
-    , allowLocalStreaming(false)
+    , allowLocalStreaming(true)
     , autoUpdate(false)
 {
 }
@@ -220,6 +220,23 @@ QString MPDConnectionDetails::description() const
     }
 }
 
+MPDConnectionDetails & MPDConnectionDetails::operator=(const MPDConnectionDetails &o)
+{
+    name=o.name;
+    hostname=o.hostname;
+    port=o.port;
+    password=o.password;
+    dir=o.dir;
+    dirReadable=o.dirReadable;
+    #ifdef ENABLE_HTTP_STREAM_PLAYBACK
+    streamUrl=o.streamUrl;
+    #endif
+    replayGain=o.replayGain;
+    allowLocalStreaming=o.allowLocalStreaming;
+    autoUpdate=o.autoUpdate;
+    return *this;
+}
+
 void MPDConnectionDetails::setDirReadable()
 {
     dirReadable=Utils::isDirReadable(dir);
@@ -1589,7 +1606,7 @@ void MPDConnection::outputs()
     }
 }
 
-void MPDConnection::enableOutput(int id, bool enable)
+void MPDConnection::enableOutput(quint32 id, bool enable)
 {
     if (sendCommand((enable ? "enableoutput " : "disableoutput ")+quote(id)).ok) {
         outputs();
@@ -1656,7 +1673,9 @@ void MPDConnection::listFolder(const QString &folder)
 
 void MPDConnection::listPlaylists()
 {
-    Response response=sendCommand("listplaylists");
+    // Don't report errors here. If user has disabled playlists, then MPD will report an error
+    // Issues #1090 #1284
+    Response response=sendCommand("listplaylists", false);
     if (response.ok) {
         QList<Playlist> playlists=MPDParseUtils::parsePlaylists(response.data);
         playlists.removeAll((Playlist(constStreamsPlayListName)));
@@ -1838,6 +1857,26 @@ void MPDConnection::search(const QString &field, const QString &value, int id)
         Response response=sendCommand(cmd);
         if (response.ok) {
             songs=MPDParseUtils::parseSongs(response.data, MPDParseUtils::Loc_Search);
+
+            if (QLatin1String("any")==field) {
+                // When searching on 'any' MPD ignores filename/paths! So, do another
+                // search on these, and combine results.
+                response=sendCommand("search file "+encodeName(value));
+                if (response.ok) {
+                    QList<Song> otherSongs=MPDParseUtils::parseSongs(response.data, MPDParseUtils::Loc_Search);
+                    if (!otherSongs.isEmpty()) {
+                        QSet<QString> fileNames;
+                        for (const auto &s: songs) {
+                            fileNames.insert(s.file);
+                        }
+                        for (const auto &s: otherSongs) {
+                            if (!fileNames.contains(s.file)) {
+                                songs.append(s);
+                            }
+                        }
+                    }
+                }
+            }
             qSort(songs);
         }
     }
@@ -1875,7 +1914,7 @@ void MPDConnection::search(const QByteArray &query, const QString &id)
                             if (val>=min && val<=max) {
                                 Response resp = sendCommand("find file " + encodeName(QString::fromUtf8(sticker.file)) , false, false);
                                 if (resp.ok) {
-                                    songs.append(MPDParseUtils::parseSong(response.data, MPDParseUtils::Loc_Search));
+                                    songs += MPDParseUtils::parseSong(resp.data, MPDParseUtils::Loc_Search);
                                 }
                             }
                         }
