@@ -141,10 +141,12 @@ private:
 
 struct MPDConnectionDetails {
     MPDConnectionDetails();
+    MPDConnectionDetails(const MPDConnectionDetails &o) { *this=o; }
     QString getName() const;
     QString description() const;
     bool isLocal() const { return hostname.startsWith('/'); }
     bool isEmpty() const { return hostname.isEmpty() || (!isLocal() && 0==port); }
+    MPDConnectionDetails & operator=(const MPDConnectionDetails &o);
     bool operator==(const MPDConnectionDetails &o) const { return hostname==o.hostname && isLocal()==o.isLocal() && (isLocal() || port==o.port) && password==o.password; }
     bool operator!=(const MPDConnectionDetails &o) const { return !(*this==o); }
     bool operator<(const MPDConnectionDetails &o) const { return name.localeAwareCompare(o.name)<0; }
@@ -331,7 +333,7 @@ public Q_SLOTS:
 
     // Output
     void outputs();
-    void enableOutput(int id, bool enable);
+    void enableOutput(quint32 id, bool enable);
 
     // Miscellaneous
     void getStats();
