@@ -36,6 +36,8 @@
 #include <QLatin1Char>
 #include <QtAlgorithms>
 #include <QUrl>
+#include <QMutex>
+#include <QMutexLocker>
 
 //static const quint8 constOnlineDiscId=0xEE;
 
@@ -384,9 +386,11 @@ struct KeyStore
 };
 
 static QHash<int, KeyStore> storeMap;
+static QMutex storeMapMutex;
 
 void Song::clearKeyStore(int location)
 {
+    QMutexLocker locker(&storeMapMutex);
     storeMap.remove(location);
 }
 
@@ -449,9 +453,11 @@ quint16 Song::setKey(int location)
         return 0;
     }
 
-    KeyStore &store=storeMap[location];
     QString songKey(albumKey());
+    QMutexLocker locker(&storeMapMutex);
+    KeyStore &store=storeMap[location];
     QHash<QString, quint16>::ConstIterator it=store.keys.find(songKey);
+
     if (it!=store.keys.end()) {
         key=it.value();
     } else {
@@ -747,30 +753,41 @@ QString Song::albumKey() const
     return albumArtist()+QLatin1Char(':')+albumId()+QLatin1Char(':')+QString::number(disc);
 }
 
+static QString basic(const QString &str)
+{
+    QStringList toStrip=QStringList() << QLatin1String("ft. ") << QLatin1String("feat. ") << QLatin1String("featuring ") << QLatin1String("f. ");
+    QStringList prefixes=QStringList() << QLatin1String(" ") << QLatin1String(" (") << QLatin1String(" [");
+
+    for (const QString &s: toStrip) {
+        for (const QString &p: prefixes) {
+            int strip = str.toLower().indexOf(p+s);
+            if (-1!=strip) {
+                return str.mid(0, strip);
+            }
+        }
+    }
+    return str;
+}
+
 QString Song::basicArtist() const
 {
     if (!albumartist.isEmpty() && (artist.isEmpty() || albumartist==artist || (albumartist.length()<artist.length() && artist.startsWith(albumartist)))) {
         return albumartist;
     }
 
-    QStringList toStrip=QStringList() << QLatin1String("ft. ") << QLatin1String("feat. ") << QLatin1String("featuring ") << QLatin1String("f. ");
-    QStringList prefixes=QStringList() << QLatin1String(" ") << QLatin1String(" (") << QLatin1String(" [");
+    return basic(artist);
+}
 
-    for (const QString &s: toStrip) {
-        for (const QString &p: prefixes) {
-            int strip = artist.toLower().indexOf(p+s);
-            if (-1!=strip) {
-                return artist.mid(0, strip);
-            }
-        }
-    }
-    return artist;
+QString Song::basicTitle() const
+{
+    return basic(title);
 }
 
 QString Song::filePath(const QString &base) const
 {
     if (isCantataStream()) {
-        return QUrl(file).path();
+        QString p = localPath();
+        return p.isEmpty() ? QUrl(file).path() : p;
     }
     if (isLocalFile()) {
         return file;
