@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2017 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -37,7 +37,7 @@ class Configuration : public QSettings
 public:
     static QLatin1String constMainGroup;
     Configuration(const QString &group=constMainGroup);
-    ~Configuration();
+    ~Configuration() override;
     
     QString      get(const QString &key, const QString &def)     { return contains(key) ? value(key).toString() : def; }
     QStringList  get(const QString &key, const QStringList &def) { return contains(key) ? value(key).toStringList() : def; }
