@@ -82,9 +82,11 @@ public:
                 } else {
                     // Load fontawesome, if it is not already loaded
                     if (fontAwesomeFontName.isEmpty()) {
-                        QStringList loadedFontFamilies = QFontDatabase::applicationFontFamilies(QFontDatabase::addApplicationFont(Utils::systemDir(QLatin1String("fonts"))+QLatin1String("fontawesome-webfont.ttf")));
+                        Q_INIT_RESOURCE(support);
+
+                        QStringList loadedFontFamilies = QFontDatabase::applicationFontFamilies(QFontDatabase::addApplicationFont(":/font.ttf"));
                         if (!loadedFontFamilies.empty()) {
-                            fontAwesomeFontName= loadedFontFamilies.at(0);
+                            fontAwesomeFontName = loadedFontFamilies.at(0);
                         }
                     }
                     fontName=fontAwesomeFontName;
@@ -96,15 +98,18 @@ public:
                     font.setBold(true);
                 } else if (pixelSize>10) {
                     static const int constScale=14;
-                    static const int constHalfScale=constScale/2;
-                    pixelSize=((pixelSize/constScale)*constScale)+((pixelSize%constScale)>=constHalfScale ? constScale : 0);
-                    pixelSize=qMin(pixelSize, rect.height());
-                    if (FontAwesome::bars==fontAwesomeIcon && pixelSize%constHalfScale) {
-                        pixelSize-=1;
-                    } else if (FontAwesome::list==fontAwesomeIcon && pixelSize%constHalfScale) {
-                        pixelSize+=1;
-                    }
 
+                    if (pixelSize>=(constScale*2)) {
+                        pixelSize=((pixelSize/constScale)*constScale);
+                    } else {
+                        static const int constHalfScale=constScale/2;
+                        pixelSize=((pixelSize/constScale)*constScale)+((pixelSize%constScale)>=constHalfScale ? constHalfScale : 0);
+                        if (pixelSize%constScale) {
+                            if (FontAwesome::list==fontAwesomeIcon) {
+                                pixelSize-=2;
+                            }
+                        }
+                    }
                 }
 
                 font.setPixelSize(pixelSize);
