@@ -58,7 +58,7 @@ const QLatin1Char Utils::constDirSep('/');
 const QLatin1String Utils::constDirSepStr("/");
 const char * Utils::constDirSepCharStr="/";
 
-static const QLatin1String constHttp("http://");
+static const QLatin1String constHttp("http:");
 
 QString Utils::fixPath(const QString &dir, bool ensureEndsInSlash)
 {
@@ -742,6 +742,11 @@ QString Utils::helper(const QString &app)
     #elif defined Q_OS_MAC
     return fixPath(QCoreApplication::applicationDirPath())+app;
     #else
+    // Check for helpers in same folder as main exe, so that can test dev versions without install.
+    QString local = fixPath(QCoreApplication::applicationDirPath())+app;
+    if (QFile::exists(local)) {
+        return local;
+    }
     return QString(INSTALL_PREFIX "/" LINUX_LIB_DIR "/")+QCoreApplication::applicationName()+constDirSep+app;
     #endif
 }
@@ -902,7 +907,7 @@ Utils::Desktop Utils::currentDe()
         } else if (desktop.contains("kde")) {
             de=KDE;
         } else if (desktop.contains("gnome") || desktop.contains("pantheon")) {
-            de=desktop.contains("ubuntu") ? Ubuntu_Gnome : Gnome;
+            de=Gnome;
         } else {
             QByteArray kde=qgetenv("KDE_FULL_SESSION");
             if ("true"==kde) {
@@ -922,9 +927,9 @@ bool Utils::useSystemTray()
     #elif defined Q_OS_WIN
     return true;
     #elif QT_QTDBUS_FOUND
-    return Ubuntu_Gnome==currentDe() || Gnome==currentDe() ? QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.StatusNotifierWatcher") : true;
+    return Gnome==currentDe() ? QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.StatusNotifierWatcher") : true;
     #else
-    return Ubuntu_Gnome!=currentDe() && Gnome!=currentDe();
+    return Gnome!=currentDe();
     #endif
 }
 
