@@ -56,12 +56,9 @@ Icons::Icons()
         streamIcon.addFile(iconFile);
     }
     if (streamIcon.isNull()) {
-        streamIcon=Icon("applications-internet");
+        streamIcon=MonoIcon::icon(FontAwesome::globe, stdColor);
     }
     podcastIcon=MonoIcon::icon(FontAwesome::podcast, stdColor);
-    audioFileIcon=Icon("audio-x-generic");
-    folderIcon=Icon("inode-directory");
-    speakerIcon=Icon(QStringList() << "speaker" << "audio-speakers" << "gnome-volume-control");
     repeatIcon=MonoIcon::icon(FontAwesome::refresh, stdColor);
     shuffleIcon=MonoIcon::icon(FontAwesome::random, stdColor);
     albumIconSmall.addFile(":album32.svg");
@@ -69,9 +66,19 @@ Icons::Icons()
     albumMonoIcon=MonoIcon::icon(":mono-album.svg", stdColor);
     artistIcon=MonoIcon::icon(":artist.svg", stdColor);
     genreIcon=MonoIcon::icon(":genre.svg", stdColor);
-    appIcon=Icon("cantata");
+    #if defined Q_OS_MAC || defined Q_OS_WIN
+    appIcon.addFile(":cantata.svg");
+    appIcon.addFile(":cantata16.png");
+    appIcon.addFile(":cantata22.png");
+    appIcon.addFile(":cantata24.png");
+    appIcon.addFile(":cantata32.png");
+    appIcon.addFile(":cantata48.png");
+    appIcon.addFile(":cantata64.png");
+    appIcon.addFile(":cantata128.png");
+    #else
+    appIcon=QIcon::fromTheme("cantata");
+    #endif
 
-    lastFmIcon=MonoIcon::icon(FontAwesome::lastfmsquare, MonoIcon::constRed, MonoIcon::constRed);
     replacePlayQueueIcon=MonoIcon::icon(FontAwesome::play, stdColor);
     appendToPlayQueueIcon=MonoIcon::icon(FontAwesome::plus, stdColor);
     centrePlayQueueOnTrackIcon=MonoIcon::icon(Qt::RightToLeft==QApplication::layoutDirection() ? FontAwesome::chevronleft : FontAwesome::chevronright, stdColor);
@@ -93,7 +100,7 @@ Icons::Icons()
     addBookmarkIcon=MonoIcon::icon(FontAwesome::bookmark, stdColor);
     audioListIcon=MonoIcon::icon(FontAwesome::music, stdColor);
     playlistListIcon=MonoIcon::icon(FontAwesome::list, stdColor);
-    dynamicListIcon=MonoIcon::icon(FontAwesome::cube, stdColor);
+    smartPlaylistIcon=MonoIcon::icon(FontAwesome::graduationcap, stdColor);
     rssListIcon=MonoIcon::icon(FontAwesome::rss, stdColor);
     savedRssListIcon=MonoIcon::icon(FontAwesome::rsssquare, stdColor);
     clockIcon=MonoIcon::icon(FontAwesome::clocko, stdColor);
@@ -109,14 +116,6 @@ Icons::Icons()
     upIcon=MonoIcon::icon(FontAwesome::chevronup, stdColor);
     downIcon=MonoIcon::icon(FontAwesome::chevrondown, stdColor);
     cancelIcon=MonoIcon::icon(FontAwesome::close, MonoIcon::constRed, MonoIcon::constRed);
-
-    #if !defined Q_OS_WIN
-    if (QLatin1String("gnome")==QIcon::themeName()) {
-        QColor col=QApplication::palette().color(QPalette::Active, QPalette::WindowText);
-        contextIcon=MonoIcon::icon(QLatin1String(":sidebar-info"), col);
-    } else
-    #endif
-        contextIcon=Icon(QStringList() << "dialog-information" << "information");
 }
 
 void Icons::initSidebarIcons()
@@ -152,7 +151,7 @@ void Icons::initToolbarIcons(QColor toolbarText)
     toolbarMenuIcon=MonoIcon::icon(FontAwesome::bars, toolbarText);
 }
 
-const Icon &Icons::albumIcon(int size, bool mono) const
+const QIcon & Icons::albumIcon(int size, bool mono) const
 {
     return !mono || albumMonoIcon.isNull()
                 ? size<48 ? albumIconSmall : albumIconLarge
